@@ -1,4 +1,4 @@
-yazi_macro::mod_pub!(package);
+yazi_macro::mod_pub!(package shared);
 
 yazi_macro::mod_flat!(args);
 
@@ -6,17 +6,21 @@ use std::process::ExitCode;
 
 use clap::Parser;
 use yazi_macro::{errln, outln};
+use yazi_shared::LOCAL_SET;
 
 #[tokio::main]
 async fn main() -> ExitCode {
-	match run().await {
+	yazi_shared::init();
+	yazi_fs::init();
+
+	match LOCAL_SET.run_until(run()).await {
 		Ok(()) => ExitCode::SUCCESS,
 		Err(e) => {
 			for cause in e.chain() {
-				if let Some(ioerr) = cause.downcast_ref::<std::io::Error>() {
-					if ioerr.kind() == std::io::ErrorKind::BrokenPipe {
-						return ExitCode::from(0);
-					}
+				if let Some(ioerr) = cause.downcast_ref::<std::io::Error>()
+					&& ioerr.kind() == std::io::ErrorKind::BrokenPipe
+				{
+					return ExitCode::from(0);
 				}
 			}
 			errln!("{e:#}").ok();
@@ -26,9 +30,6 @@ async fn main() -> ExitCode {
 }
 
 async fn run() -> anyhow::Result<()> {
-	yazi_shared::init();
-	yazi_fs::init();
-
 	if std::env::args_os().nth(1).is_some_and(|s| s == "-V" || s == "--version") {
 		outln!(
 			"Ya {} ({} {})",
@@ -67,27 +68,9 @@ async fn run() -> anyhow::Result<()> {
 			match cmd {
 				CommandPkg::Add { ids } => pkg.add_many(&ids).await?,
 				CommandPkg::Delete { ids } => pkg.delete_many(&ids).await?,
-				CommandPkg::Install => pkg.install(false).await?,
+				CommandPkg::Install => pkg.install().await?,
 				CommandPkg::List => pkg.print()?,
-				CommandPkg::Upgrade => pkg.install(true).await?,
-			}
-		}
-
-		Command::Pack(cmd) => {
-			package::init()?;
-			outln!(
-				"WARNING: `ya pack` is deprecated, use the new `ya pkg` instead. See https://github.com/sxyazi/yazi/pull/2770 for more details."
-			)?;
-			if cmd.install {
-				package::Package::load().await?.install(false).await?;
-			} else if cmd.list {
-				package::Package::load().await?.print()?;
-			} else if cmd.upgrade {
-				package::Package::load().await?.install(true).await?;
-			} else if let Some(uses) = cmd.add {
-				package::Package::load().await?.add_many(&uses).await?;
-			} else if let Some(uses) = cmd.delete {
-				package::Package::load().await?.delete_many(&uses).await?;
+				CommandPkg::Upgrade { ids } => pkg.upgrade_many(&ids).await?,
 			}
 		}
 
