@@ -1,7 +1,8 @@
 use anyhow::{Result, bail};
 use serde::Deserialize;
+use yazi_fs::Splatter;
 
-#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Ord, PartialOrd, Hash)]
+#[derive(Clone, Debug, Deserialize, Eq, Hash, Ord, PartialEq, PartialOrd)]
 pub struct OpenerRule {
 	pub run:    String,
 	#[serde(default)]
@@ -16,7 +17,6 @@ pub struct OpenerRule {
 }
 
 impl OpenerRule {
-	#[inline]
 	pub fn desc(&self) -> String {
 		if !self.desc.is_empty() {
 			self.desc.clone()
@@ -36,11 +36,12 @@ impl OpenerRule {
 
 		#[cfg(unix)]
 		{
-			self.spread = self.run.contains("$@") || self.run.contains("$*");
+			self.spread =
+				Splatter::<()>::spread(&self.run) || self.run.contains("$@") || self.run.contains("$*");
 		}
 		#[cfg(windows)]
 		{
-			self.spread = self.run.contains("%*");
+			self.spread = Splatter::<()>::spread(&self.run) || self.run.contains("%*");
 		}
 
 		Ok(self)
