@@ -1,10 +1,10 @@
 use ratatui::{text::{Line, Text}, widgets::{Paragraph, Wrap}};
-use yazi_shared::url::Url;
+use yazi_shared::{scheme::Encode as EncodeScheme, strand::ToStrand, url::{Url, UrlBuf}};
 
-use super::{Offset, Origin, Position};
+use super::{Offset, Position};
 use crate::YAZI;
 
-#[derive(Default)]
+#[derive(Debug, Default)]
 pub struct InputCfg {
 	pub title:      String,
 	pub value:      String,
@@ -15,25 +15,26 @@ pub struct InputCfg {
 	pub completion: bool,
 }
 
-#[derive(Default)]
+#[derive(Debug, Default)]
 pub struct PickCfg {
 	pub title:    String,
 	pub items:    Vec<String>,
 	pub position: Position,
 }
 
-#[derive(Default)]
+#[derive(Debug, Default)]
 pub struct ConfirmCfg {
 	pub position: Position,
 	pub title:    Line<'static>,
-	pub content:  Paragraph<'static>,
+	pub body:     Paragraph<'static>,
 	pub list:     Paragraph<'static>,
 }
 
 impl InputCfg {
-	pub fn cd() -> Self {
+	pub fn cd(cwd: Url) -> Self {
 		Self {
-			title: YAZI.input.cd_title.to_owned(),
+			title: YAZI.input.cd_title.clone(),
+			value: if cwd.kind().is_local() { String::new() } else { EncodeScheme(cwd).to_string() },
 			position: Position::new(YAZI.input.cd_origin, YAZI.input.cd_offset),
 			completion: true,
 			..Default::default()
@@ -42,7 +43,7 @@ impl InputCfg {
 
 	pub fn create(dir: bool) -> Self {
 		Self {
-			title: YAZI.input.create_title[dir as usize].to_owned(),
+			title: YAZI.input.create_title[dir as usize].clone(),
 			position: Position::new(YAZI.input.create_origin, YAZI.input.create_offset),
 			..Default::default()
 		}
@@ -50,7 +51,7 @@ impl InputCfg {
 
 	pub fn rename() -> Self {
 		Self {
-			title: YAZI.input.rename_title.to_owned(),
+			title: YAZI.input.rename_title.clone(),
 			position: Position::new(YAZI.input.rename_origin, YAZI.input.rename_offset),
 			..Default::default()
 		}
@@ -58,7 +59,7 @@ impl InputCfg {
 
 	pub fn filter() -> Self {
 		Self {
-			title: YAZI.input.filter_title.to_owned(),
+			title: YAZI.input.filter_title.clone(),
 			position: Position::new(YAZI.input.filter_origin, YAZI.input.filter_offset),
 			realtime: true,
 			..Default::default()
@@ -67,7 +68,7 @@ impl InputCfg {
 
 	pub fn find(prev: bool) -> Self {
 		Self {
-			title: YAZI.input.find_title[prev as usize].to_owned(),
+			title: YAZI.input.find_title[prev as usize].clone(),
 			position: Position::new(YAZI.input.find_origin, YAZI.input.find_offset),
 			realtime: true,
 			..Default::default()
@@ -84,7 +85,7 @@ impl InputCfg {
 
 	pub fn shell(block: bool) -> Self {
 		Self {
-			title: YAZI.input.shell_title[block as usize].to_owned(),
+			title: YAZI.input.shell_title[block as usize].clone(),
 			position: Position::new(YAZI.input.shell_origin, YAZI.input.shell_offset),
 			..Default::default()
 		}
@@ -106,51 +107,51 @@ impl InputCfg {
 impl ConfirmCfg {
 	fn new(
 		title: String,
-		(origin, offset): (Origin, Offset),
-		content: Option<Text<'static>>,
+		position: Position,
+		body: Option<Text<'static>>,
 		list: Option<Text<'static>>,
 	) -> Self {
 		Self {
-			position: Position::new(origin, offset),
-			title:    Line::raw(title),
-			content:  content.map(|c| Paragraph::new(c).wrap(Wrap { trim: false })).unwrap_or_default(),
-			list:     list.map(|l| Paragraph::new(l).wrap(Wrap { trim: false })).unwrap_or_default(),
+			position,
+			title: Line::raw(title),
+			body: body.map(|b| Paragraph::new(b).wrap(Wrap { trim: false })).unwrap_or_default(),
+			list: list.map(|l| Paragraph::new(l).wrap(Wrap { trim: false })).unwrap_or_default(),
 		}
 	}
 
-	pub fn trash(urls: &[yazi_shared::url::Url]) -> Self {
+	pub fn trash(urls: &[yazi_shared::url::UrlBuf]) -> Self {
 		Self::new(
 			Self::replace_number(&YAZI.confirm.trash_title, urls.len()),
-			(YAZI.confirm.trash_origin, YAZI.confirm.trash_offset),
+			YAZI.confirm.trash_position(),
 			None,
-			Self::truncate_list(urls.iter(), urls.len(), 100),
+			Self::truncate_list(urls, urls.len(), 100),
 		)
 	}
 
-	pub fn delete(urls: &[yazi_shared::url::Url]) -> Self {
+	pub fn delete(urls: &[yazi_shared::url::UrlBuf]) -> Self {
 		Self::new(
 			Self::replace_number(&YAZI.confirm.delete_title, urls.len()),
-			(YAZI.confirm.delete_origin, YAZI.confirm.delete_offset),
+			YAZI.confirm.delete_position(),
 			None,
-			Self::truncate_list(urls.iter(), urls.len(), 100),
+			Self::truncate_list(urls, urls.len(), 100),
 		)
 	}
 
-	pub fn overwrite(url: &Url) -> Self {
+	pub fn overwrite(url: &UrlBuf) -> Self {
 		Self::new(
-			YAZI.confirm.overwrite_title.to_owned(),
-			(YAZI.confirm.overwrite_origin, YAZI.confirm.overwrite_offset),
-			Some(Text::raw(&YAZI.confirm.overwrite_content)),
-			Some(url.to_string().into()),
+			YAZI.confirm.overwrite_title.clone(),
+			YAZI.confirm.overwrite_position(),
+			Some(Text::raw(&YAZI.confirm.overwrite_body)),
+			Some(url.to_strand().into_string_lossy().into()),
 		)
 	}
 
 	pub fn quit(len: usize, names: Vec<String>) -> Self {
 		Self::new(
 			Self::replace_number(&YAZI.confirm.quit_title, len),
-			(YAZI.confirm.quit_origin, YAZI.confirm.quit_offset),
-			Some(Text::raw(&YAZI.confirm.quit_content)),
-			Self::truncate_list(names.into_iter(), len, 10),
+			YAZI.confirm.quit_position(),
+			Some(Text::raw(&YAZI.confirm.quit_body)),
+			Self::truncate_list(names, len, 10),
 		)
 	}
 
@@ -158,25 +159,24 @@ impl ConfirmCfg {
 		tpl.replace("{n}", &n.to_string()).replace("{s}", if n > 1 { "s" } else { "" })
 	}
 
-	fn truncate_list(
-		it: impl Iterator<Item = impl Into<String>>,
-		len: usize,
-		max: usize,
-	) -> Option<Text<'static>> {
+	fn truncate_list<I>(it: I, len: usize, max: usize) -> Option<Text<'static>>
+	where
+		I: IntoIterator,
+		I::Item: ToStrand,
+	{
 		let mut lines = Vec::with_capacity(len.min(max + 1));
-		for (i, s) in it.enumerate() {
+		for (i, s) in it.into_iter().enumerate() {
 			if i >= max {
 				lines.push(format!("... and {} more", len - max));
 				break;
 			}
-			lines.push(s.into());
+			lines.push(s.to_strand().into_string_lossy());
 		}
 		Some(Text::from_iter(lines))
 	}
 }
 
 impl PickCfg {
-	#[inline]
 	fn max_height(len: usize) -> u16 {
 		YAZI.pick.open_offset.height.min(YAZI.pick.border().saturating_add(len as u16))
 	}
@@ -184,7 +184,7 @@ impl PickCfg {
 	pub fn open(items: Vec<String>) -> Self {
 		let max_height = Self::max_height(items.len());
 		Self {
-			title: YAZI.pick.open_title.to_owned(),
+			title: YAZI.pick.open_title.clone(),
 			items,
 			position: Position::new(YAZI.pick.open_origin, Offset {
 				height: max_height,
