@@ -1,29 +1,31 @@
 use std::path::PathBuf;
 
-use anyhow::{Result, bail};
-use serde::{Deserialize, Serialize};
+use anyhow::{Context, Result, anyhow, bail};
+use serde::Deserialize;
 use yazi_codegen::{DeserializeOver1, DeserializeOver2};
-use yazi_fs::expand_path;
-use yazi_shared::theme::Style;
+use yazi_fs::{Xdg, ok_or_not_found};
 
 use super::{Filetype, Flavor, Icon};
+use crate::{Style, normalize_path};
 
-#[derive(Deserialize, DeserializeOver1, Serialize)]
+#[derive(Deserialize, DeserializeOver1)]
 pub struct Theme {
-	pub flavor:  Flavor,
-	pub mgr:     Mgr,
-	pub tabs:    Tabs,
-	pub mode:    Mode,
-	pub status:  Status,
-	pub which:   Which,
-	pub confirm: Confirm,
-	pub spot:    Spot,
-	pub notify:  Notify,
-	pub pick:    Pick,
-	pub input:   Input,
-	pub cmp:     Cmp,
-	pub tasks:   Tasks,
-	pub help:    Help,
+	pub flavor:    Flavor,
+	pub app:       App,
+	pub mgr:       Mgr,
+	pub tabs:      Tabs,
+	pub mode:      Mode,
+	pub indicator: Indicator,
+	pub status:    Status,
+	pub which:     Which,
+	pub confirm:   Confirm,
+	pub spot:      Spot,
+	pub notify:    Notify,
+	pub pick:      Pick,
+	pub input:     Input,
+	pub cmp:       Cmp,
+	pub tasks:     Tasks,
+	pub help:      Help,
 
 	// File-specific styles
 	#[serde(skip_serializing)]
@@ -32,31 +34,32 @@ pub struct Theme {
 	pub icon:     Icon,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
-pub struct Mgr {
-	cwd: Style,
+#[derive(Deserialize, DeserializeOver2)]
+pub struct App {
+	pub overall: Style,
+}
 
-	// Hovered
-	hovered:         Style,
-	preview_hovered: Style,
+#[derive(Deserialize, DeserializeOver2)]
+pub struct Mgr {
+	pub cwd: Style,
 
 	// Find
-	find_keyword:  Style,
-	find_position: Style,
+	pub find_keyword:  Style,
+	pub find_position: Style,
 
 	// Symlink
-	symlink_target: Style,
+	pub symlink_target: Style,
 
 	// Marker
-	marker_copied:   Style,
-	marker_cut:      Style,
-	marker_marked:   Style,
-	marker_selected: Style,
+	pub marker_copied:   Style,
+	pub marker_cut:      Style,
+	pub marker_marked:   Style,
+	pub marker_selected: Style,
 
 	// Count
-	count_copied:   Style,
-	count_cut:      Style,
-	count_selected: Style,
+	pub count_copied:   Style,
+	pub count_cut:      Style,
+	pub count_selected: Style,
 
 	// Border
 	pub border_symbol: String,
@@ -66,7 +69,7 @@ pub struct Mgr {
 	pub syntect_theme: PathBuf,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Tabs {
 	pub active:   Style,
 	pub inactive: Style,
@@ -75,13 +78,13 @@ pub struct Tabs {
 	pub sep_outer: TabsSep,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct TabsSep {
 	pub open:  String,
 	pub close: String,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Mode {
 	pub normal_main: Style,
 	pub normal_alt:  Style,
@@ -93,7 +96,21 @@ pub struct Mode {
 	pub unset_alt:  Style,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
+pub struct Indicator {
+	pub parent:  Style,
+	pub current: Style,
+	pub preview: Style,
+	pub padding: IndicatorPadding,
+}
+
+#[derive(Deserialize, DeserializeOver2)]
+pub struct IndicatorPadding {
+	pub open:  String,
+	pub close: String,
+}
+
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Status {
 	pub overall:   Style,
 	pub sep_left:  StatusSep,
@@ -112,13 +129,13 @@ pub struct Status {
 	pub progress_error:  Style,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct StatusSep {
 	pub open:  String,
 	pub close: String,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Which {
 	pub cols: u8,
 	pub mask: Style,
@@ -130,19 +147,19 @@ pub struct Which {
 	pub separator_style: Style,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Confirm {
-	pub border:  Style,
-	pub title:   Style,
-	pub content: Style,
-	pub list:    Style,
+	pub border: Style,
+	pub title:  Style,
+	pub body:   Style,
+	pub list:   Style,
 
 	pub btn_yes:    Style,
 	pub btn_no:     Style,
 	pub btn_labels: [String; 2],
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Spot {
 	pub border: Style,
 	pub title:  Style,
@@ -151,7 +168,7 @@ pub struct Spot {
 	pub tbl_cell: Style,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Notify {
 	pub title_info:  Style,
 	pub title_warn:  Style,
@@ -162,14 +179,14 @@ pub struct Notify {
 	pub icon_error: String,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Pick {
 	pub border:   Style,
 	pub active:   Style,
 	pub inactive: Style,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Input {
 	pub border:   Style,
 	pub title:    Style,
@@ -177,7 +194,7 @@ pub struct Input {
 	pub selected: Style,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Cmp {
 	pub border:   Style,
 	pub active:   Style,
@@ -188,14 +205,14 @@ pub struct Cmp {
 	pub icon_command: String,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Tasks {
 	pub border:  Style,
 	pub title:   Style,
 	pub hovered: Style,
 }
 
-#[derive(Deserialize, DeserializeOver2, Serialize)]
+#[derive(Deserialize, DeserializeOver2)]
 pub struct Help {
 	pub on:   Style,
 	pub run:  Style,
@@ -206,6 +223,12 @@ pub struct Help {
 }
 
 impl Theme {
+	pub(crate) fn read() -> Result<String> {
+		let p = Xdg::config_dir().join("theme.toml");
+		ok_or_not_found(std::fs::read_to_string(&p))
+			.with_context(|| format!("Failed to read theme {p:?}"))
+	}
+
 	pub(crate) fn reshape(mut self, light: bool) -> Result<Self> {
 		if self.which.cols < 1 || self.which.cols > 3 {
 			bail!("[which].cols must be between 1 and 3");
@@ -213,9 +236,16 @@ impl Theme {
 
 		self.icon = self.icon.reshape()?;
 
-		self.mgr.syntect_theme =
-			self.flavor.syntect_path(light).unwrap_or_else(|| expand_path(&self.mgr.syntect_theme));
+		self.mgr.syntect_theme = self
+			.flavor
+			.syntect_path(light)
+			.or_else(|| normalize_path(self.mgr.syntect_theme))
+			.ok_or(anyhow!("[mgr].syntect_theme must be either empty or an absolute path."))?;
 
 		Ok(self)
 	}
 }
+
+impl App {
+	pub fn bg_color(&self) -> String { self.overall.bg.map(|c| c.to_string()).unwrap_or_default() }
+}
