@@ -1,24 +1,27 @@
+use std::iter;
+
 use ratatui::layout::Rect;
 use yazi_adapter::Dimension;
 use yazi_config::popup::{Origin, Position};
-use yazi_fs::File;
-use yazi_shared::url::Url;
+use yazi_fs::Splatable;
+use yazi_shared::url::{AsUrl, Url, UrlBuf};
+use yazi_watcher::Watcher;
 
-use super::{Mimetype, Tabs, Watcher, Yanked};
+use super::{Mimetype, Tabs, Yanked};
 use crate::tab::{Folder, Tab};
 
 pub struct Mgr {
 	pub tabs:   Tabs,
 	pub yanked: Yanked,
 
-	pub(super) watcher: Watcher,
-	pub mimetype:       Mimetype,
+	pub watcher:  Watcher,
+	pub mimetype: Mimetype,
 }
 
 impl Mgr {
 	pub fn make() -> Self {
 		Self {
-			tabs:   Tabs::make(),
+			tabs:   Default::default(),
 			yanked: Default::default(),
 
 			watcher:  Watcher::serve(),
@@ -39,7 +42,7 @@ impl Mgr {
 
 impl Mgr {
 	#[inline]
-	pub fn cwd(&self) -> &Url { self.active().cwd() }
+	pub fn cwd(&self) -> &UrlBuf { self.active().cwd() }
 
 	#[inline]
 	pub fn active(&self) -> &Tab { self.tabs.active() }
@@ -47,31 +50,35 @@ impl Mgr {
 	#[inline]
 	pub fn active_mut(&mut self) -> &mut Tab { self.tabs.active_mut() }
 
-	#[inline]
-	pub fn current(&self) -> &Folder { &self.active().current }
-
 	#[inline]
 	pub fn current_mut(&mut self) -> &mut Folder { &mut self.active_mut().current }
 
-	#[inline]
-	pub fn parent(&self) -> Option<&Folder> { self.active().parent.as_ref() }
-
 	#[inline]
 	pub fn parent_mut(&mut self) -> Option<&mut Folder> { self.active_mut().parent.as_mut() }
+}
 
-	#[inline]
-	pub fn hovered(&self) -> Option<&File> { self.active().hovered() }
+impl Splatable for Mgr {
+	fn tab(&self) -> usize { self.tabs.cursor }
 
-	#[inline]
-	pub fn hovered_folder(&self) -> Option<&Folder> { self.active().hovered_folder() }
+	fn selected(&self, tab: usize, mut idx: Option<usize>) -> impl Iterator<Item = Url<'_>> {
+		idx = idx.and_then(|i| i.checked_sub(1));
+		tab
+			.checked_sub(1)
+			.and_then(|tab| self.tabs.get(tab))
+			.map(|tab| tab.selected_or_hovered())
+			.unwrap_or_else(|| Box::new(iter::empty()))
+			.skip(idx.unwrap_or(0))
+			.take(if idx.is_some() { 1 } else { usize::MAX })
+			.map(|u| u.as_url())
+	}
 
-	#[inline]
-	pub fn selected_or_hovered(&self) -> Box<dyn Iterator<Item = &Url> + '_> {
-		self.tabs.active().selected_or_hovered()
+	fn hovered(&self, tab: usize) -> Option<Url<'_>> {
+		tab
+			.checked_sub(1)
+			.and_then(|tab| self.tabs.get(tab))
+			.and_then(|tab| tab.hovered())
+			.map(|h| h.url.as_url())
 	}
 
-	#[inline]
-	pub fn hovered_and_selected(&self) -> Box<dyn Iterator<Item = &Url> + '_> {
-		self.tabs.active().hovered_and_selected()
-	}
+	fn yanked(&self) -> impl Iterator<Item = Url<'_>> { self.yanked.iter().map(|u| u.as_url()) }
 }
