@@ -2,12 +2,15 @@ use std::mem;
 
 use yazi_config::{LAYOUT, YAZI};
 use yazi_dds::Pubsub;
-use yazi_fs::{File, Files, FilesOp, FolderStage, Step, cha::Cha};
+use yazi_fs::{File, Files, FilesOp, FolderStage, cha::Cha};
+use yazi_macro::err;
+use yazi_parser::Step;
 use yazi_proxy::MgrProxy;
-use yazi_shared::{Id, url::{Url, Urn, UrnBuf}};
+use yazi_shared::{Id, path::{AsPath, PathBufDyn, PathDyn}, url::UrlBuf};
+use yazi_widgets::Scrollable;
 
 pub struct Folder {
-	pub url:   Url,
+	pub url:   UrlBuf,
 	pub cha:   Cha,
 	pub files: Files,
 	pub stage: FolderStage,
@@ -16,7 +19,7 @@ pub struct Folder {
 	pub cursor: usize,
 
 	pub page:  usize,
-	pub trace: Option<UrnBuf>,
+	pub trace: Option<PathBufDyn>,
 }
 
 impl Default for Folder {
@@ -24,7 +27,7 @@ impl Default for Folder {
 		Self {
 			url:    Default::default(),
 			cha:    Default::default(),
-			files:  Files::new(YAZI.mgr.show_hidden),
+			files:  Files::new(YAZI.mgr.show_hidden.get()),
 			stage:  Default::default(),
 			offset: Default::default(),
 			cursor: Default::default(),
@@ -34,13 +37,13 @@ impl Default for Folder {
 	}
 }
 
-impl From<&Url> for Folder {
-	fn from(url: &Url) -> Self { Self { url: url.clone(), ..Default::default() } }
+impl<T: Into<UrlBuf>> From<T> for Folder {
+	fn from(value: T) -> Self { Self { url: value.into(), ..Default::default() } }
 }
 
 impl Folder {
 	pub fn update(&mut self, op: FilesOp) -> bool {
-		let (stage, revision) = (self.stage, self.files.revision);
+		let (stage, revision) = (self.stage.clone(), self.files.revision);
 		match op {
 			FilesOp::Full(_, _, cha) => {
 				(self.cha, self.stage) = (cha, FolderStage::Loaded);
@@ -54,8 +57,8 @@ impl Folder {
 			FilesOp::Done(_, cha, ticket) if ticket == self.files.ticket() => {
 				(self.cha, self.stage) = (cha, FolderStage::Loaded);
 			}
-			FilesOp::IOErr(_, kind) => {
-				(self.cha, self.stage) = (Cha::default(), FolderStage::Failed(kind));
+			FilesOp::IOErr(_, ref err) => {
+				(self.cha, self.stage) = (Cha::default(), FolderStage::Failed(err.clone()));
 			}
 			_ => {}
 		}
@@ -78,39 +81,34 @@ impl Folder {
 		}
 
 		self.trace = self.trace.take_if(|_| !self.files.is_empty() || self.stage.is_loading());
-		self.repos(self.trace.clone());
+		self.repos(None);
 
-		(stage, revision) != (self.stage, self.files.revision)
+		(&stage, revision) != (&self.stage, self.files.revision)
 	}
 
 	pub fn update_pub(&mut self, tab: Id, op: FilesOp) -> bool {
-		let old = self.stage;
-		if !self.update(op) {
-			return false;
-		} else if self.stage != old {
-			Pubsub::pub_from_load(tab, &self.url, self.stage);
+		if self.update(op) {
+			err!(Pubsub::pub_after_load(tab, &self.url, &self.stage));
+			return true;
 		}
-		true
+		false
 	}
 
 	pub fn arrow(&mut self, step: impl Into<Step>) -> bool {
-		let new = (step.into() as Step).add(self.cursor, self.files.len(), LAYOUT.get().limit());
 		let mut b = if self.files.is_empty() {
 			(mem::take(&mut self.cursor), mem::take(&mut self.offset)) != (0, 0)
-		} else if new > self.cursor {
-			self.next(new)
 		} else {
-			self.prev(new)
+			self.scroll(step)
 		};
 
-		self.trace = self.hovered().filter(|_| b).map(|h| h.urn_owned()).or(self.trace.take());
+		self.trace = self.hovered().filter(|_| b).map(|h| h.urn().into()).or(self.trace.take());
 		b |= self.squeeze_offset();
 
 		self.sync_page(false);
 		b
 	}
 
-	pub fn hover(&mut self, urn: &Urn) -> bool {
+	pub fn hover(&mut self, urn: PathDyn) -> bool {
 		if self.hovered().map(|h| h.urn()) == Some(urn) {
 			return self.arrow(0);
 		}
@@ -119,13 +117,18 @@ impl Folder {
 		self.arrow(new - self.cursor as isize)
 	}
 
-	#[inline]
-	pub fn repos(&mut self, urn: Option<impl AsRef<Urn>>) -> bool {
-		if let Some(u) = urn { self.hover(u.as_ref()) } else { self.arrow(0) }
+	pub fn repos(&mut self, urn: Option<PathDyn>) -> bool {
+		if let Some(u) = urn {
+			self.hover(u)
+		} else if let Some(u) = &self.trace {
+			self.hover(u.clone().as_path())
+		} else {
+			self.arrow(0)
+		}
 	}
 
 	pub fn sync_page(&mut self, force: bool) {
-		let limit = LAYOUT.get().limit();
+		let limit = LAYOUT.get().folder_limit();
 		if limit == 0 {
 			return;
 		}
@@ -136,45 +139,12 @@ impl Folder {
 		}
 	}
 
-	fn next(&mut self, new: usize) -> bool {
-		let old = (self.cursor, self.offset);
-		let len = self.files.len();
-
-		let limit = LAYOUT.get().limit();
-		let scrolloff = (limit / 2).min(YAZI.mgr.scrolloff as usize);
-
-		self.cursor = new;
-		self.offset = if self.cursor < (self.offset + limit).min(len).saturating_sub(scrolloff) {
-			self.offset.min(len.saturating_sub(1))
-		} else {
-			len.saturating_sub(limit).min(self.offset + self.cursor - old.0)
-		};
-
-		old != (self.cursor, self.offset)
-	}
-
-	fn prev(&mut self, new: usize) -> bool {
-		let old = (self.cursor, self.offset);
-
-		let limit = LAYOUT.get().limit();
-		let scrolloff = (limit / 2).min(YAZI.mgr.scrolloff as usize);
-
-		self.cursor = new;
-		self.offset = if self.cursor < self.offset + scrolloff {
-			self.offset.saturating_sub(old.0 - self.cursor)
-		} else {
-			self.offset.min(self.files.len().saturating_sub(1))
-		};
-
-		old != (self.cursor, self.offset)
-	}
-
 	fn squeeze_offset(&mut self) -> bool {
 		let old = self.offset;
 		let len = self.files.len();
 
-		let limit = LAYOUT.get().limit();
-		let scrolloff = (limit / 2).min(YAZI.mgr.scrolloff as usize);
+		let limit = LAYOUT.get().folder_limit();
+		let scrolloff = (limit / 2).min(YAZI.mgr.scrolloff.get() as usize);
 
 		self.offset = if self.cursor < (self.offset + limit).min(len).saturating_sub(scrolloff) {
 			len.saturating_sub(limit).min(self.offset)
@@ -190,12 +160,27 @@ impl Folder {
 	#[inline]
 	pub fn hovered(&self) -> Option<&File> { self.files.get(self.cursor) }
 
+	#[inline]
+	pub fn hovered_mut(&mut self) -> Option<&mut File> { self.files.get_mut(self.cursor) }
+
 	pub fn paginate(&self, page: usize) -> &[File] {
 		let len = self.files.len();
-		let limit = LAYOUT.get().limit();
+		let limit = LAYOUT.get().folder_limit();
 
 		let start = (page.saturating_sub(1) * limit).min(len.saturating_sub(1));
 		let end = ((page + 2) * limit).min(len);
 		&self.files[start..end]
 	}
 }
+
+impl Scrollable for Folder {
+	fn total(&self) -> usize { self.files.len() }
+
+	fn limit(&self) -> usize { LAYOUT.get().folder_limit() }
+
+	fn scrolloff(&self) -> usize { (self.limit() / 2).min(YAZI.mgr.scrolloff.get() as usize) }
+
+	fn cursor_mut(&mut self) -> &mut usize { &mut self.cursor }
+
+	fn offset_mut(&mut self) -> &mut usize { &mut self.offset }
+}
