@@ -1,5 +1,6 @@
 use std::mem;
 
+use yazi_fs::Splatter;
 use yazi_parser::tasks::ProcessOpenOpt;
 
 use super::Tasks;
@@ -8,6 +9,7 @@ impl Tasks {
 	// TODO: remove
 	pub fn open_shell_compat(&self, mut opt: ProcessOpenOpt) {
 		if opt.spread {
+			opt.cmd = Splatter::new(&opt.args).splat(opt.cmd);
 			self.scheduler.process_open(opt);
 			return;
 		}
@@ -15,18 +17,20 @@ impl Tasks {
 			return;
 		}
 		if opt.args.len() == 2 {
+			opt.cmd = Splatter::new(&opt.args).splat(opt.cmd);
 			self.scheduler.process_open(opt);
 			return;
 		}
 		let hovered = mem::take(&mut opt.args[0]);
 		for target in opt.args.into_iter().skip(1) {
+			let args = vec![hovered.clone(), target];
 			self.scheduler.process_open(ProcessOpenOpt {
-				cwd:    opt.cwd.clone(),
-				cmd:    opt.cmd.clone(),
-				args:   vec![hovered.clone(), target],
-				block:  opt.block,
+				cwd: opt.cwd.clone(),
+				cmd: Splatter::new(&args).splat(&opt.cmd),
+				args,
+				block: opt.block,
 				orphan: opt.orphan,
-				done:   None,
+				done: None,
 				spread: opt.spread,
 			});
 		}
