@@ -1,12 +1,10 @@
-#![allow(clippy::if_same_then_else, clippy::module_inception, clippy::unit_arg)]
-
 #[cfg(all(not(target_os = "macos"), not(target_os = "windows")))]
 #[global_allocator]
 static GLOBAL: tikv_jemallocator::Jemalloc = tikv_jemallocator::Jemalloc;
 
-yazi_macro::mod_pub!(app cmp confirm help input lives mgr notify pick spot tasks which);
+yazi_macro::mod_pub!(app cmp confirm help input mgr notify pick spot tasks which);
 
-yazi_macro::mod_flat!(context executor logs panic root router signals term);
+yazi_macro::mod_flat!(dispatcher executor logs panic root router signals term);
 
 #[tokio::main]
 async fn main() -> anyhow::Result<()> {
@@ -22,6 +20,8 @@ async fn main() -> anyhow::Result<()> {
 
 	yazi_config::init()?;
 
+	yazi_vfs::init();
+
 	yazi_adapter::init()?;
 
 	yazi_boot::init();
@@ -30,10 +30,13 @@ async fn main() -> anyhow::Result<()> {
 
 	yazi_dds::init();
 
+	yazi_widgets::init();
+
+	yazi_watcher::init();
+
 	yazi_plugin::init()?;
 
-	yazi_core::init();
-
 	yazi_dds::serve();
-	app::App::serve().await
+
+	yazi_shared::LOCAL_SET.run_until(app::App::serve()).await
 }
