@@ -1,3 +1,4 @@
+use anyhow::Result;
 use yazi_config::{KEYMAP, keymap::{Chord, ChordCow, Key}};
 use yazi_macro::emit;
 use yazi_shared::Layer;
@@ -9,33 +10,30 @@ pub(super) struct Router<'a> {
 }
 
 impl<'a> Router<'a> {
-	#[inline]
 	pub(super) fn new(app: &'a mut App) -> Self { Self { app } }
 
-	#[inline]
-	pub(super) fn route(&mut self, key: Key) -> bool {
-		let cx = &mut self.app.cx;
-		let layer = cx.layer();
+	pub(super) fn route(&mut self, key: Key) -> Result<bool> {
+		let core = &mut self.app.core;
+		let layer = core.layer();
 
-		if cx.help.visible && cx.help.r#type(&key) {
-			return true;
+		if core.help.visible && core.help.r#type(&key)? {
+			return Ok(true);
 		}
-		if cx.input.visible && cx.input.r#type(&key) {
-			return true;
+		if core.input.visible && core.input.r#type(&key)? {
+			return Ok(true);
 		}
 
 		use Layer as L;
-		match layer {
+		Ok(match layer {
 			L::App => unreachable!(),
 			L::Mgr | L::Tasks | L::Spot | L::Pick | L::Input | L::Confirm | L::Help => {
 				self.matches(layer, key)
 			}
 			L::Cmp => self.matches(L::Cmp, key) || self.matches(L::Input, key),
-			L::Which => cx.which.r#type(key),
-		}
+			L::Which => core.which.r#type(key),
+		})
 	}
 
-	#[inline]
 	fn matches(&mut self, layer: Layer, key: Key) -> bool {
 		for chord @ Chord { on, .. } in KEYMAP.get(layer) {
 			if on.is_empty() || on[0] != key {
@@ -43,7 +41,7 @@ impl<'a> Router<'a> {
 			}
 
 			if on.len() > 1 {
-				self.app.cx.which.show_with(key, layer);
+				self.app.core.which.show_with(key, layer);
 			} else {
 				emit!(Seq(ChordCow::from(chord).into_seq()));
 			}
