@@ -1,30 +1,31 @@
-use std::{fs::Metadata, path::Path};
+use std::fs::Metadata;
 
 use bitflags::bitflags;
+use yazi_shared::strand::AsStrand;
 
 bitflags! {
 	#[derive(Clone, Copy, Debug, Default, PartialEq, Eq)]
 	pub struct ChaKind: u8 {
-		const DIR    = 0b00000001;
-
-		const HIDDEN = 0b00000010;
-		const LINK   = 0b00000100;
-		const ORPHAN = 0b00001000;
-
-		const DUMMY  = 0b00010000;
-		#[cfg(windows)]
-		const SYSTEM = 0b00100000;
+		const FOLLOW = 0b0000_0001;
+		const HIDDEN = 0b0000_0010;
+		const SYSTEM = 0b0000_0100;
+		const DUMMY  = 0b0000_1000;
 	}
 }
 
 impl ChaKind {
 	#[inline]
-	pub(super) fn hidden(_path: &Path, _meta: &Metadata) -> Self {
+	pub(super) fn hidden<T>(_name: T, _meta: &Metadata) -> Self
+	where
+		T: AsStrand,
+	{
 		let mut me = Self::empty();
 
 		#[cfg(unix)]
-		if yazi_shared::url::Urn::new(_path).is_hidden() {
-			me |= Self::HIDDEN;
+		{
+			if _name.as_strand().starts_with(".") {
+				me |= Self::HIDDEN;
+			}
 		}
 		#[cfg(windows)]
 		{
