@@ -1,7 +1,5 @@
 use mlua::{IntoLua, Lua, Table};
-use yazi_binding::{Id, Url, Urn};
-
-use crate::{bindings::Cha, file::File};
+use yazi_binding::{Cha, File, Id, Path, Url};
 
 pub(super) struct FilesOp(yazi_fs::FilesOp);
 
@@ -36,7 +34,7 @@ impl FilesOp {
 		Ok(Self(yazi_fs::FilesOp::Size(
 			url.into(),
 			sizes
-				.pairs::<Urn, u64>()
+				.pairs::<Path, u64>()
 				.map(|r| r.map(|(urn, size)| (urn.into(), size)))
 				.collect::<mlua::Result<_>>()?,
 		)))
