@@ -89,7 +89,7 @@ fn peek_async(
 				},
 			)?;
 
-			let plugin = LOADER.load_once(&lua, &cmd.name)?;
+			let plugin = LOADER.load_once(&lua, &cmd.name).await?;
 			let job = lua.create_table_from([
 				("area", Rect::from(LAYOUT.get().preview).into_lua(&lua)?),
 				("args", Sendable::args_to_table_ref(&lua, &cmd.args)?.into_lua(&lua)?),
