@@ -34,6 +34,7 @@ fn stage_1(lua: &'static Lua) -> Result<()> {
 	crate::process::install(lua)?;
 	yazi_binding::File::install(lua)?;
 	yazi_binding::Url::install(lua)?;
+	yazi_binding::Path::install(lua)?;
 
 	// Addons
 	lua.load(preset!("ya")).set_name("ya.lua").exec()?;
@@ -67,6 +68,6 @@ fn stage_2(lua: &'static Lua) -> mlua::Result<()> {
 		block_on(lua.load(b).set_name("init.lua").exec_async())?;
 	}
 
-	runtime_mut!(lua)?.initing = false;
+	runtime_mut!(lua)?.blocking = false;
 	Ok(())
 }
