@@ -1,18 +1,15 @@
 use tokio::sync::oneshot;
 use yazi_config::popup::ConfirmCfg;
-use yazi_macro::emit;
-use yazi_shared::event::Cmd;
+use yazi_macro::{emit, relay};
 
 pub struct ConfirmProxy;
 
 impl ConfirmProxy {
-	#[inline]
 	pub async fn show(cfg: ConfirmCfg) -> bool { Self::show_rx(cfg).await.unwrap_or(false) }
 
-	#[inline]
 	pub fn show_rx(cfg: ConfirmCfg) -> oneshot::Receiver<bool> {
 		let (tx, rx) = oneshot::channel();
-		emit!(Call(Cmd::new("confirm:show").with_any("tx", tx).with_any("cfg", cfg)));
+		emit!(Call(relay!(confirm:show).with_any("tx", tx).with_any("cfg", cfg)));
 		rx
 	}
 }
