@@ -1,17 +1,16 @@
 use std::ffi::OsString;
 
-use tokio::sync::mpsc;
-use yazi_shared::url::Url;
+use yazi_shared::{CompletionToken, Id, url::UrlCow};
 
 use super::ShellOpt;
 
 // --- Block
 #[derive(Debug)]
-pub struct ProcessInBlock {
-	pub id:   usize,
-	pub cwd:  Url,
-	pub cmd:  OsString,
-	pub args: Vec<OsString>,
+pub(crate) struct ProcessInBlock {
+	pub(crate) id:   Id,
+	pub(crate) cwd:  UrlCow<'static>,
+	pub(crate) cmd:  OsString,
+	pub(crate) args: Vec<UrlCow<'static>>,
 }
 
 impl From<ProcessInBlock> for ShellOpt {
@@ -22,11 +21,11 @@ impl From<ProcessInBlock> for ShellOpt {
 
 // --- Orphan
 #[derive(Debug)]
-pub struct ProcessInOrphan {
-	pub id:   usize,
-	pub cwd:  Url,
-	pub cmd:  OsString,
-	pub args: Vec<OsString>,
+pub(crate) struct ProcessInOrphan {
+	pub(crate) id:   Id,
+	pub(crate) cwd:  UrlCow<'static>,
+	pub(crate) cmd:  OsString,
+	pub(crate) args: Vec<UrlCow<'static>>,
 }
 
 impl From<ProcessInOrphan> for ShellOpt {
@@ -37,12 +36,12 @@ impl From<ProcessInOrphan> for ShellOpt {
 
 // --- Bg
 #[derive(Debug)]
-pub struct ProcessInBg {
-	pub id:     usize,
-	pub cwd:    Url,
-	pub cmd:    OsString,
-	pub args:   Vec<OsString>,
-	pub cancel: mpsc::Receiver<()>,
+pub(crate) struct ProcessInBg {
+	pub(crate) id:   Id,
+	pub(crate) cwd:  UrlCow<'static>,
+	pub(crate) cmd:  OsString,
+	pub(crate) args: Vec<UrlCow<'static>>,
+	pub(crate) done: CompletionToken,
 }
 
 impl From<ProcessInBg> for ShellOpt {
