@@ -1,18 +1,20 @@
-use yazi_shared::event::CmdCow;
+use anyhow::Result;
+use yazi_macro::{act, succ};
+use yazi_shared::{data::Data, event::CmdCow};
 
 use crate::input::{Input, InputMode};
 
 impl Input {
-	pub fn execute(&mut self, cmd: CmdCow) {
+	pub fn execute(&mut self, cmd: CmdCow) -> Result<Data> {
 		macro_rules! on {
 			($name:ident) => {
 				if cmd.name == stringify!($name) {
-					return self.$name(cmd);
+					return act!($name, self, cmd);
 				}
 			};
 			($name:ident, $alias:literal) => {
 				if cmd.name == $alias {
-					return self.$name(cmd);
+					return act!($name, self, cmd);
 				}
 			};
 		}
@@ -33,16 +35,18 @@ impl Input {
 
 				on!(undo);
 				on!(redo);
+
+				on!(casefy);
 			}
 			InputMode::Insert => {
 				on!(visual);
 
 				on!(backspace);
 				on!(kill);
-
-				on!(complete);
 			}
 			InputMode::Replace => {}
 		}
+
+		succ!();
 	}
 }
